# SWM

SWM (Server, Worker and Monitor/Manager), a cooperative approach to background task management for web applications.


# Installation

pip install swm


# Usage

Please take a look in the examples folder :)
